@@ -28,11 +28,10 @@ def plantuml(key, value, format, _):
             dest = filename + '.' + filetype
 
             if not os.path.isfile(dest):
-                txt = code.encode(sys.getfilesystemencoding())
-                if not txt.startswith("@start"):
-                    txt = "@startuml\n" + txt + "\n@enduml\n"
+                if not code.startswith("@start"):
+                    code = "@startuml\n" + code + "\n@enduml\n"
                 with open(src, "w") as f:
-                    f.write(txt)
+                    f.write(code)
 
                 call(["java", "-jar", "plantuml.jar", "-t"+filetype, src])
                 sys.stderr.write('Created image ' + dest + '\n')
